@@ -170,7 +170,8 @@ class Building(Entity, Mapping):
             query = query.filter(floors.c.number.in_(list(floor_numbers)))
         return query.all()
 
-    def fetch_apartments(self, available_only=False, floors=None):
+    def fetch_apartments(self, available_only=False, floors=None,
+                         room_count=None):
         query = session.query(Apartment)\
                        .filter(apartments.c.project_title==self.project_title,
                                apartments.c.quarter_number==self.quarter_number,
@@ -180,6 +181,8 @@ class Building(Entity, Mapping):
             query = query.filter(apartments.c.floor_number.in_(floor_list))
         if available_only:
             query = query.filter(apartments.c.status == 1)
+        if room_count:
+            query = query.filter(apartments.c.room_count == room_count)
         return query.all()
 
     def get_sections(self, reverse=False):
